About

Struct About 

#[non_exhaustive]
pub struct About { pub pkg_name: Txt, pub pkg_authors: Box<[Txt]>, pub version: Version, pub app_id: Txt, pub app: Txt, pub org: Txt, pub description: Txt, pub homepage: Txt, pub license: Txt, pub has_about: bool, pub meta: Vec<(Txt, Txt)>, pub is_test: bool, }
Metadata about the app and main crate.

See about for more details.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
pkg_name: Txt

package.name

Cargo crate name for the entry crate.

pkg_authors: Box<[Txt]>

package.authors

Cargo crate authors for the entry crate.

version: Version

package.version

Cargo crate version for the entry crate.

app_id: Txt

package.metadata.zng.about.app_id

Fully qualified unique name for the application. Is a list of one or more dot-separated identifiers, each identifier starts with letter, identifiers contains only letters, digits and underscore. A reverse DNS name is recommended.

If the metadata is not set an id is derived from "qualifier", org and app values.

app: Txt

package.metadata.zng.about.app

App display name.

If the metadata is not set the pkg_name is used.

org: Txt

package.metadata.zng.about.org

Organization display name.

If the metadata is not set the first pkg_authors is used.

description: Txt

package.description

Short description of the app.

homepage: Txt

package.homepage

Valid website about the app.

license: Txt

package.license

License title of the app.

has_about: bool

If package.metadata.zng.about is set on the Cargo.toml manifest.

The presence of this section is used by cargo zng res to find the main crate if the workspace has multiple bin crates.

meta: Vec<(Txt, Txt)>

package.metadata.zng.about.*

Any other unknown string metadata.

is_test: bool

If app was started in a cfg(test) build binary.

Implementations

Source

impl About

pub fn crate_name(&self) -> Txt

The pkg_name in snake_case.

pub fn qualifier(&self) -> Txt

The first components of app_id except the last two.

For app id "br.com.company.product" the qualifier is "br.com". For id "company.product" the qualifier is empty.

pub fn get(&self, key: &str) -> Option<Txt>

Get the value.

The key can be an entry of meta, the name of a field or the name of a value method.

Source

impl About

pub fn parse_manifest(cargo_toml: &str) -> Result<Self, Error>

Parse a Cargo.toml string.